/*
** Module   : LockAdministrator.java
** Abstract : Record lock administration API
**
** Copyright (c) 2004-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------------------Description-----------------------------
** 001 ECF 20090801  @43499  Created initial version. Record lock
**                           administration API. Currently, the only feature
**                           is to collect a snapshot of all locks held by a
**                           LockManager instance.
** 002 ECF 20131028          Moved to lock sub-package.
*/

package com.goldencode.p2j.persist.lock;

import java.util.*;
import com.goldencode.p2j.admin.*;

/**
 * Interface which enables the collection of record lock information snapshots
 * during server execution.  One instance of a class which implements this
 * interface should be created for each physical database managed by a P2J
 * server, except for the dedicated temporary table database.
 */
public interface LockAdministrator
{
   /**
    * Gather record lock information for the associated, physical database.
    * 
    * @return  A list of {@link com.goldencode.p2j.admin.RecordLockInfo
    *          RecordLockInfo} objects.  If no locks currently are being held,
    *          the list will be empty, but it must not be <code>null</code>.
    */
   public List<RecordLockInfo> collectRecordLockInfo();
}
