/*
** Module   : LockUnavailableException.java
** Abstract : Exception thrown when a lock cannot be acquired for a no-wait lock request
**
** Copyright (c) 2005-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------------------Description-----------------------------
** 001 ECF 20051207   @23682 Created initial version. An exception thrown
**                           to indicate that a lock could not be acquired
**                           for a database record.
** 002 ECF 20131028          Moved to lock sub-package.
*/ 

package com.goldencode.p2j.persist.lock;

import com.goldencode.p2j.*;
import com.goldencode.p2j.persist.*;

/**
 * This exception is thrown by the persistence service layer to indicate that
 * a request to lock a record, issued with the no-wait option, could not be
 * fulfilled, because another user holds the lock.
 * <p>
 * Supports the assignment of an error number at construction.
 */
public class LockUnavailableException
extends PersistenceException
{
   /**
    * Constructor which accepts an error message only.
    *
    * @param   message
    *          Error message.
    */
   public LockUnavailableException(String message)
   {
      super(message);
   }
    
   /**
    * Constructor which accepts an error message and an error number.
    *
    * @param   message
    *          Error message.
    * @param   number
    *          Error number.
    */
   public LockUnavailableException(String message, int number)
   {
      super(message, number);
   }
}
